#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
ezgooey
-------
Copyright (c) 2020 Adam Twardoch <adam+github@twardoch.com>
MIT license. Python 3.8+

See `ezgooey.ez` and `ezgooey.logging` for details.
"""
__version__ = "1.3.2"

__all__ = ['ez', 'logging']
